@@ -7,11 +7,13 @@ Common functions and variables fetched from AWS.
 """
 import re
 import secrets
+from copy import deepcopy
 from string import ascii_lowercase
 from time import sleep
 
 from botocore.exceptions import ClientError
 from compose_x_common.aws import get_assume_role_session, validate_iam_role_arn
+from compose_x_common.aws.arns import ARNS_PER_TAGGINGAPI_TYPE
 from compose_x_common.compose_x_common import keyisset
 from tabulate import tabulate
 
@@ -152,18 +154,18 @@ def handle_search_results(
             name,
             aws_resource_search,
         )
-    if arns and isinstance(name, str):
-        return handle_multi_results(
-            arns,
-            name,
-            aws_resource_search,
-            res_types[aws_resource_search]["regexp"],
-            allow_multi=allow_multi,
-        )
-    elif not name and len(arns) == 1:
-        LOG.info(f"Matched {aws_resource_search} to AWS Resource")
-        return arns[0]
-    elif not allow_multi and not name and len(arns) > 1:
+    # if arns and isinstance(name, str):
+    #     return handle_multi_results(
+    #         arns,
+    #         name,
+    #         aws_resource_search,
+    #         res_types[aws_resource_search],
+    #         allow_multi=allow_multi,
+    #     )
+    # elif not name and len(arns) == 1:
+    #     LOG.info(f"Matched {aws_resource_search} to AWS Resource")
+    #     return arns[0]
+    elif not allow_multi and len(arns) > 1:
         raise LookupError(
             f"More than one resource {name}:{aws_resource_search} was found with the current tags."
             "Found",
@@ -171,6 +173,8 @@ def handle_search_results(
         )
     elif allow_multi and len(arns) > 1:
         return arns
+    else:
+        return arns[0]
 
 
 def validate_search_input(res_types, res_type):
@@ -203,14 +207,9 @@ def find_aws_resource_arn_from_tags_api(
     :param dict types: Additional types to match.
     :return:
     """
-    res_types = {
-        "secretsmanager:secret": {
-            "regexp": r"(?:^arn:aws(?:-[a-z]+)?:secretsmanager:[\w-]+:[0-9]{12}:secret:)([\S]+)(?:-[A-Za-z0-9]{1,6})$"
-        },
-    }
+    res_types = deepcopy(ARNS_PER_TAGGINGAPI_TYPE)
     if types is not None and isinstance(types, dict):
         res_types.update(types)
-    validate_search_input(res_types, aws_resource_search)
     search_tags = (
         define_tagsgroups_filter_tags(info["Tags"]) if keyisset("Tags", info) else ()
     )
@@ -227,29 +226,6 @@ def find_aws_resource_arn_from_tags_api(
     )
 
 
-def get_region_azs(session):
-    """Function to return the AZ from a given region. Uses default region for this
-
-    :param boto3.session.Session session: Boto3 session
-
-    :return: list of AZs in the given region
-    :rtype: list
-    """
-    return session.client("ec2").describe_availability_zones()["AvailabilityZones"]
-
-
-def get_account_id(session):
-    """
-    Function to get the current session account ID
-
-    :param boto3.session.Session session: Boto3 Session to make the API call.
-
-    :return: account ID
-    :rtype: str
-    """
-    return session.client("sts").get_caller_identity()["Account"]
-
-
 def assert_can_create_stack(client, name):
     """
     Checks whether a stack already exists or not
