@@ -5,15 +5,27 @@
 """
 Module to define the ComposeX Resources into a simple object to make it easier to navigate through.
 """
+
+import json
 import warnings
 from copy import deepcopy
 from re import sub
 
-from compose_x_common.compose_x_common import keyisset, keypresent
+from boto3.session import Session
+from compose_x_common.aws import get_account_id
+from compose_x_common.compose_x_common import (
+    attributes_to_mapping,
+    keyisset,
+    keypresent,
+)
 from troposphere import Export, FindInMap, GetAtt, Output, Ref, Sub
 from troposphere.ecs import Environment
 
 from ecs_composex.common import LOG, NONALPHANUM
+from ecs_composex.common.aws import (
+    define_lookup_role_from_info,
+    find_aws_resource_arn_from_tags_api,
+)
 from ecs_composex.common.cfn_conditions import define_stack_name
 from ecs_composex.common.cfn_params import Parameter
 from ecs_composex.common.ecs_composex import CFN_EXPORT_DELIMITER as DELIM
@@ -52,12 +64,18 @@ def set_lookup_resources(x_resources, res_key):
     :return: list of resources to import from Lookup
     :rtype: list[XResource] x_resources:
     """
-    lookup_resources = [
-        resource
-        for resource in x_resources
-        if resource.lookup
-        and not (resource.properties or resource.parameters or resource.use)
-    ]
+    lookup_resources = []
+    for resource in x_resources:
+        if resource.lookup:
+            if resource.properties or resource.parameters or resource.use:
+                LOG.warning(
+                    f"{resource.module_name}.{resource.name} is set for Lookup"
+                    " but has other properties set. Voiding them"
+                )
+                resource.properties = {}
+                resource.parameters = {}
+                resource.use = {}
+            lookup_resources.append(resource)
     return lookup_resources
 
 
@@ -147,8 +165,12 @@ class XResource(object):
         Init the class
         :param str name: Name of the resource in the template
         :param dict definition: The definition of the resource as-is
+        :param ecs_composex.common.settings.ComposeXSettings settings:
         """
         self.name = name
+        self.arn = None
+        self.cloud_control_attributes_mapping = {}
+        self.native_attributes_mapping = {}
         self.module_name = module_name
         self.mapping_key = mapping_key
         if self.mapping_key is None:
@@ -170,6 +192,12 @@ class XResource(object):
             if not keyisset("Lookup", self.definition)
             else self.definition["Lookup"]
         )
+        if self.lookup:
+            self.lookup_session = define_lookup_role_from_info(
+                self.lookup, settings.session
+            )
+        else:
+            self.lookup_session = settings.session
         if keyisset("Properties", self.definition) and not self.lookup:
             self.properties = self.definition["Properties"]
         elif not keyisset("Properties", self.definition) and keypresent(
@@ -209,6 +237,88 @@ class XResource(object):
     def __repr__(self):
         return self.logical_name
 
+    def cloud_control_attributes_mapping_lookup(
+        self, resource_type, resource_id, **kwargs
+    ):
+        """
+        Method to map the resource properties to the CCAPI description
+        :return:
+        """
+        client = self.lookup_session.client("cloudcontrol")
+        try:
+            props_r = client.get_resource(
+                TypeName=resource_type, Identifier=resource_id, **kwargs
+            )
+            properties = json.loads(props_r["ResourceDescription"]["Properties"])
+            props = attributes_to_mapping(
+                properties, self.cloud_control_attributes_mapping
+            )
+            return props
+        except client.exceptions.UnsupportedActionException:
+            LOG.warning("Resource not yet supported by Cloud Control API")
+            return {}
+
+    def native_attributes_mapping_lookup(self, account_id, resource_id, function):
+        properties = function(self, account_id, resource_id)
+        if self.native_attributes_mapping:
+            conform_mapping = attributes_to_mapping(
+                properties, self.native_attributes_mapping
+            )
+            return conform_mapping
+        return properties
+
+    def lookup_resource(
+        self,
+        arn_re,
+        native_lookup_function,
+        cfn_resource_type,
+        tagging_api_id,
+        subattribute_key=None,
+    ):
+        """
+        Method to self-identify properties
+        :return:
+        """
+        lookup_attributes = self.lookup
+        if subattribute_key is not None:
+            lookup_attributes = self.lookup[subattribute_key]
+        if keyisset("Arn", lookup_attributes):
+            arn_parts = arn_re.match(lookup_attributes["Arn"])
+            if not arn_parts:
+                raise KeyError(
+                    f"{self.module_name}.{self.name} - ARN {lookup_attributes['Arn']} is not valid. Must match",
+                    arn_re.pattern,
+                )
+            self.arn = lookup_attributes["Arn"]
+            resource_id = arn_parts.group("id")
+            account_id = arn_parts.group("accountid")
+        elif keyisset("Tags", lookup_attributes):
+            self.arn = find_aws_resource_arn_from_tags_api(
+                lookup_attributes, self.lookup_session, tagging_api_id
+            )
+            arn_parts = arn_re.match(self.arn)
+            resource_id = arn_parts.group("id")
+            account_id = arn_parts.group("accountid")
+        else:
+            raise KeyError(
+                f"{self.module_name}.{self.name} - You must specify Arn or Tags to identify existing resource"
+            )
+        if not self.arn:
+            raise LookupError(
+                f"{self.module_name}.{self.name} - Failed to find the AWS Resource with given tags"
+            )
+        props = {}
+        _account_id = get_account_id(self.lookup_session)
+        if _account_id == account_id and self.cloud_control_attributes_mapping:
+            props = self.cloud_control_attributes_mapping_lookup(
+                cfn_resource_type, resource_id
+            )
+        if not props:
+            props = self.native_attributes_mapping_lookup(
+                account_id, resource_id, native_lookup_function
+            )
+        self.mappings = props
+
     def debug_families_targets(self):
         """
         Method to troubleshoot family and service mapping
