@@ -17,18 +17,14 @@ import jsonschema
 import yaml
 from botocore.exceptions import ClientError
 from cfn_flip.yaml_dumper import LongCleanDumper
-from compose_x_common.aws import validate_iam_role_arn
+from compose_x_common.aws import get_account_id, get_region_azs, validate_iam_role_arn
 from compose_x_common.compose_x_common import keyisset
 from compose_x_render.compose_x_render import ComposeDefinition
 from importlib_resources import files as pkg_files
 
 from ecs_composex import __version__
 from ecs_composex.common import LOG, NONALPHANUM
-from ecs_composex.common.aws import (
-    get_account_id,
-    get_cross_role_session,
-    get_region_azs,
-)
+from ecs_composex.common.aws import get_cross_role_session
 from ecs_composex.common.cfn_params import USE_FLEET_T
 from ecs_composex.common.compose_networks import ComposeNetwork
 from ecs_composex.common.compose_services import ComposeFamily, ComposeService
@@ -175,6 +171,7 @@ class ComposeXSettings(object):
         self.ecs_cluster_platform_override = None
         self.ecs_cluster_providers = []
         self.ignore_ecr_findings = keyisset(self.ecr_arg, kwargs)
+        self.x_resources_void = []
 
     def evaluate_private_namespace(self):
         """
@@ -375,7 +372,7 @@ class ComposeXSettings(object):
         )
         content_def = ComposeDefinition(files, content)
         self.compose_content = content_def.definition
-        source = pkg_files("ecs_composex_specs").joinpath("compose-spec.json")
+        source = pkg_files("ecs_composex").joinpath("specs/compose-spec.json")
         print(source)
         resolver = jsonschema.RefResolver(
             f"file://{path.abspath(path.dirname(source))}/", None
