@@ -1,4 +1,4 @@
-﻿#  -*- coding: utf-8 -*-
+#  -*- coding: utf-8 -*-
 # SPDX-License-Identifier: MPL-2.0
 # Copyright 2020-2021 John Mille <john@compose-x.io>
 
@@ -6,7 +6,6 @@
 Module to manage IAM policies to grant access to ECS Services to DynamodbTables
 """
 
-from ecs_composex.dynamodb.dynamodb_aws import lookup_dynamodb_config
 from ecs_composex.dynamodb.dynamodb_params import (
     MAPPINGS_KEY,
     RES_KEY,
@@ -19,21 +18,6 @@ from ecs_composex.resource_settings import (
 )
 
 
-def create_dyndb_mappings(mapping, resources, settings):
-    """
-    Function to create the resource mapping for SQS Queues.
-
-    :param dict mapping:
-    :param list resources:
-    :param ecs_composex.common.settings.ComposeXSettings settings:
-    :return:
-    """
-    for res in resources:
-        res_config = lookup_dynamodb_config(res.lookup, settings.session)
-        res.mappings = res_config
-        mapping.update({res.logical_name: res_config})
-
-
 def dynamodb_to_ecs(resources, services_stack, res_root_stack, settings):
     """
     Function to apply SQS settings to ECS Services
