@@ -7,13 +7,15 @@ Module to add Prometheus scraper for ECS tasks.
 """
 import json
 import re
+from os import path
 
 import yaml
 
 try:
     from yaml import CDumper as Dumper
+    from yaml import CLoader as Loader
 except ImportError:
-    from yaml import Dumper
+    from yaml import Dumper, Loader
 
 from troposphere import (
     AWS_ACCOUNT_ID,
@@ -28,7 +30,7 @@ from troposphere.iam import PolicyType
 from troposphere.ssm import Parameter as SSMParameter
 
 from ecs_composex.common import keyisset
-from ecs_composex.common.cfn_params import Parameter
+from ecs_composex.common.cfn_params import STACK_ID_SHORT, Parameter
 from ecs_composex.common.compose_services import ComposeService
 from ecs_composex.ecs import ecs_params
 
@@ -47,38 +49,53 @@ NGINX_EXPORTER_IMAGE_PARAMETER = Parameter(
 METRICS_DEFAULT_PATH = r"/metrics"
 
 
-def set_cw_prometheus_config_parameter(family):
+def set_cw_prometheus_config_parameter(family, options):
     """
     Function to add the SSM Parameter representing the Prometheus scrapper config
     :param ecs_composex.common.compose_services.ComposeFamily family:
     :return: parameter
     :rtype: troposphere.ssm.Parameter
     """
-    value_py = {
-        "global": {
-            "scrape_interval": "1m",
-            "scrape_timeout": "10s",
-        },
-        "scrape_configs": [
-            {
-                "job_name": "cwagent-ecs-file-sd-config",
-                "sample_limit": 10000,
-                "file_sd_configs": [{"files": ["/tmp/cwagent_ecs_auto_sd.yaml"]}],
-            }
-        ],
-    }
+    scrape_config = {}
+    if keyisset("ScrapingConfiguration", options):
+        scrape_config = options["ScrapingConfiguration"]
+    if keyisset("ScrapingConfigurationFile", scrape_config):
+        with open(
+            path.abspath(scrape_config["ScrapingConfigurationFile"]), "r"
+        ) as config_fd:
+            value_py = yaml.load(config_fd.read(), Loader=Loader)
+    else:
+        value_py = {
+            "global": {
+                "scrape_interval": "1m"
+                if not keyisset("Interval", scrape_config)
+                else scrape_config["Interval"],
+                "scrape_timeout": "10s"
+                if not keyisset("Timeout", scrape_config)
+                else scrape_config["Timeout"],
+            },
+            "scrape_configs": [
+                {
+                    "job_name": "${STACK_SHORT_ID}-cwagent-ecs-file-sd-config",
+                    "sample_limit": 10000,
+                    "file_sd_configs": [{"files": ["/tmp/cwagent_ecs_auto_sd.yaml"]}],
+                }
+            ],
+        }
 
     parameter = SSMParameter(
         f"{family.logical_name}SSMPrometheusConfig",
         Tier="Standard",
         Type="String",
         Name=Sub(
-            f"/ecs/config/prometheus/${{{ecs_params.CLUSTER_NAME.title}}}/${{{ecs_params.SERVICE_NAME_T}}}"
+            f"/ecs/config/prometheus/${{{ecs_params.CLUSTER_NAME.title}}}/${{STACK_SHORT_ID}}"
+            f"/${{{ecs_params.SERVICE_NAME_T}}}",
+            STACK_SHORT_ID=STACK_ID_SHORT,
         ),
         Description=Sub(
             f"Prometheus Scraping SSM Parameter for ECS Cluster: ${{{ecs_params.CLUSTER_NAME.title}}}"
         ),
-        Value=yaml.dump(value_py, Dumper=Dumper),
+        Value=Sub(yaml.dump(value_py, Dumper=Dumper), STACK_SHORT_ID=STACK_ID_SHORT),
     )
     family.template.add_resource(parameter)
     return parameter
@@ -205,7 +222,7 @@ def get_ngnix_processor(
     ]
     ecs_sd_config["task_definition_list"].append(
         {
-            "sd_job_name": "nginx-prometheus-exporter",
+            "sd_job_name": "${STACK_SHORT_ID}-nginx-prometheus-exporter",
             "sd_metrics_path": METRICS_DEFAULT_PATH
             if not keyisset("ExporterPath", nginx_config)
             else nginx_config["ExporterPath"],
@@ -219,7 +236,7 @@ def get_ngnix_processor(
     )
     ecs_sd_config["service_name_list_for_tasks"].append(
         {
-            "sd_job_name": "nginx-prometheus-exporter",
+            "sd_job_name": "${STACK_SHORT_ID}-nginx-prometheus-exporter",
             "sd_metrics_path": METRICS_DEFAULT_PATH
             if not keyisset("ExporterPath", nginx_config)
             else nginx_config["ExporterPath"],
@@ -273,7 +290,7 @@ def get_jmx_processor(family, ecs_sd_config, jmx_config):
     ]
     ecs_sd_config["task_definition_list"].append(
         {
-            "sd_job_name": "javajmx-prometheus-exporter",
+            "sd_job_name": "${STACK_SHORT_ID}-javajmx-prometheus-exporter",
             "sd_metrics_path": METRICS_DEFAULT_PATH
             if not keyisset("ExporterPath", jmx_config)
             else jmx_config["ExporterPath"],
@@ -302,7 +319,7 @@ def process_custom_rules(family, ecs_sd_config, options, emf_processors):
         emf_processors["metric_declaration"] += rule["EmfProcessors"]
         ecs_sd_config["service_name_list_for_tasks"].append(
             {
-                "sd_job_name": f"service-def-{family.logical_name}-custom-sd-{count}",
+                "sd_job_name": f"${{STACK_SHORT_ID}}-service-def-{family.logical_name}-custom-sd-{count}",
                 "sd_metrics_path": METRICS_DEFAULT_PATH
                 if not keyisset("ExporterPath", rule)
                 else rule["ExporterPath"],
@@ -312,7 +329,7 @@ def process_custom_rules(family, ecs_sd_config, options, emf_processors):
         )
         ecs_sd_config["task_definition_list"].append(
             {
-                "sd_job_name": f"task-def-{family.logical_name}-custom-sd-{count}",
+                "sd_job_name": f"${{STACK_SHORT_ID}}-task-def-{family.logical_name}-custom-sd-{count}",
                 "sd_metrics_path": METRICS_DEFAULT_PATH
                 if not keyisset("ExporterPath", rule)
                 else rule["ExporterPath"],
@@ -391,12 +408,17 @@ def set_cw_config_parameter(family, **options):
         Tier="Intelligent-Tiering",
         Type="String",
         Name=Sub(
-            f"/ecs/config/cw_agent_config/${{{ecs_params.CLUSTER_NAME.title}}}/${{{ecs_params.SERVICE_NAME_T}}}"
+            f"/ecs/config/cw_agent_config/${{{ecs_params.CLUSTER_NAME.title}}}/${{STACK_SHORT_ID}}"
+            f"/${{{ecs_params.SERVICE_NAME_T}}}",
+            STACK_SHORT_ID=STACK_ID_SHORT,
         ),
         Description=Sub(
             f"Prometheus Scraping SSM Parameter for ECS Cluster: ${{{ecs_params.CLUSTER_NAME.title}}}"
         ),
-        Value=Sub(json.dumps(value_py, ensure_ascii=True, sort_keys=True, indent=2)),
+        Value=Sub(
+            json.dumps(value_py, ensure_ascii=True, sort_keys=True, indent=2),
+            STACK_SHORT_ID=STACK_ID_SHORT,
+        ),
     )
     family.template.add_resource(parameter)
     return parameter
@@ -545,7 +567,7 @@ def add_cw_agent_to_family(family, **options):
     Function to add the CW Agent to the task family for additional monitoring
     :param ecs_composex.common.compose_services.ComposeFamily family:
     """
-    prometheus_config = set_cw_prometheus_config_parameter(family)
+    prometheus_config = set_cw_prometheus_config_parameter(family, options)
     cw_agent_config = set_cw_config_parameter(family, **options)
     family.add_service(
         define_cloudwatch_agent(family, prometheus_config, cw_agent_config)
