@@ -1,14 +1,17 @@
-﻿#  -*- coding: utf-8 -*-
+#   -*- coding: utf-8 -*-
 # SPDX-License-Identifier: MPL-2.0
 # Copyright 2020-2021 John Mille <john@compose-x.io>
 
 from troposphere import FindInMap
 
-from ecs_composex.common import LOG
+from ecs_composex.common import LOG, add_parameters
 from ecs_composex.common.stacks import ComposeXStack
 from ecs_composex.ecs import ecs_params, metadata
 from ecs_composex.ecs.ecs_service_network_config import set_compose_services_ingress
-from ecs_composex.ecs.ecs_template import generate_services
+from ecs_composex.ecs.ecs_template import (
+    initialize_family_services,
+    initialize_service_template,
+)
 
 
 class ServiceStack(ComposeXStack):
@@ -44,26 +47,48 @@ def associate_services_to_root_stack(root_stack, settings, vpc_stack=None):
     :param ecs_composex.common.stacks.ComposeXStack vpc_stack:
     :return:
     """
-    generate_services(settings)
-    for family_name in settings.families:
-        family = settings.families[family_name]
+    for family_name, family in settings.families.items():
+        family.template = initialize_service_template(family.logical_name)
         family.stack = ServiceStack(
             family.logical_name,
             stack_template=family.template,
             stack_parameters=family.stack_parameters,
         )
+        initialize_family_services(settings, family)
+        add_parameters(
+            family.template,
+            [
+                family.task_role.arn["ImportParameter"],
+                family.task_role.name["ImportParameter"],
+                family.exec_role.arn["ImportParameter"],
+                family.exec_role.name["ImportParameter"],
+            ],
+        )
         family.stack.Parameters.update(
             {
-                ecs_params.CLUSTER_NAME.title: settings.ecs_cluster,
+                ecs_params.CLUSTER_NAME.title: settings.ecs_cluster.cluster_identifier,
                 ecs_params.FARGATE_VERSION.title: FindInMap(
                     "ComposeXDefaults", "ECS", "PlatformVersion"
                 ),
+                family.task_role.arn["ImportParameter"].title: family.task_role.arn[
+                    "ImportValue"
+                ],
+                family.task_role.name["ImportParameter"].title: family.task_role.name[
+                    "ImportValue"
+                ],
+                family.exec_role.arn["ImportParameter"].title: family.exec_role.arn[
+                    "ImportValue"
+                ],
+                family.exec_role.name["ImportParameter"].title: family.exec_role.name[
+                    "ImportValue"
+                ],
+                ecs_params.SERVICE_HOSTNAME.title: family.family_hostname,
             }
         )
-        if settings.ecs_cluster_platform_override:
-            family.launch_type = settings.ecs_cluster_platform_override
+        if settings.ecs_cluster.platform_override:
+            family.launch_type = settings.ecs_cluster.platform_override
             family.stack.Parameters.update(
-                {ecs_params.LAUNCH_TYPE.title: settings.ecs_cluster_platform_override}
+                {ecs_params.LAUNCH_TYPE.title: settings.ecs_cluster.platform_override}
             )
         if not vpc_stack:
             family.stack.no_vpc_parameters(settings)
