@@ -7,9 +7,22 @@ Module to import Policies templates from AWS SAM policies templates.
 """
 
 import json
+import warnings
 
 from importlib_resources import files as pkg_files
-from samtranslator.policy_templates_data import POLICY_TEMPLATES_FILE
+
+from ..common import setup_logging
+
+try:
+    from samtranslator.policy_templates_data import POLICY_TEMPLATES_FILE
+
+    USE_SAM_POLICIES = True
+except ImportError:
+    POLICY_TEMPLATES_FILE = None
+    USE_SAM_POLICIES = False
+    warnings.warn("Cannot use AWS SAM Polices. aws-sam-translator is not installed.")
+
+LOG = setup_logging()
 
 
 def import_and_cleanse_policies():
@@ -19,7 +32,9 @@ def import_and_cleanse_policies():
     :return: The policies
     :rtype: dict
     """
-
+    if not USE_SAM_POLICIES:
+        LOG.error("Unable to load SAM Policies templates due to Library load error")
+        return {}
     with open(POLICY_TEMPLATES_FILE, "r") as policies_fd:
         policies_orig = json.loads(policies_fd.read())["Templates"]
     import_policies = {}
