@@ -10,14 +10,14 @@ from compose_x_common.compose_x_common import keyisset
 from troposphere import FindInMap, Select
 
 from ecs_composex.common import LOG
-from ecs_composex.rds.rds_aws import lookup_rds_resource, validate_rds_lookup
 from ecs_composex.rds.rds_params import (
     DB_ENDPOINT_PORT,
     DB_SECRET_ARN,
     DB_SECRET_T,
     DB_SG,
+    RES_KEY,
 )
-from ecs_composex.tcp_resources_settings import (
+from ecs_composex.rds_resources_settings import (
     add_secret_to_container,
     add_secrets_access_policy,
     add_security_group_ingress,
@@ -50,7 +50,7 @@ def handle_import_dbs_to_services(db, rds_mapping, target, mapping_name):
                 target,
             )
         add_secrets_access_policy(
-            target[0].template,
+            target[0],
             FindInMap(mapping_name, db.logical_name, DB_SECRET_T),
             db.logical_name,
         )
@@ -61,38 +61,11 @@ def handle_import_dbs_to_services(db, rds_mapping, target, mapping_name):
     add_security_group_ingress(
         target[0].stack,
         db.logical_name,
-        sg_id=Select(
-            0, FindInMap(mapping_name, db.logical_name, "VpcSecurityGroupIds")
-        ),
-        port=FindInMap(mapping_name, db.logical_name, "Port"),
+        sg_id=FindInMap(mapping_name, db.logical_name, "VpcSecurityGroupId"),
+        port=FindInMap(mapping_name, db.logical_name, DB_ENDPOINT_PORT.title),
     )
 
 
-def create_rds_db_config_mapping(db, db_config):
-    """
-
-    :param db:
-    :param db_config:
-    :return:
-    """
-    mapping = {
-        db.logical_name: {
-            "VpcSecurityGroupIds": [
-                k["VpcSecurityGroupId"]
-                for k in db_config["VpcSecurityGroups"]
-                if k["Status"] == "active"
-            ],
-            "Port": db_config["Port"],
-            db.logical_name: db_config["DBClusterIdentifier"]
-            if db_config["Engine"].startswith("aurora")
-            else db_config["DBInstanceIdentifier"],
-        }
-    }
-    if keyisset(DB_SECRET_T, db_config):
-        mapping[db.logical_name][DB_SECRET_T] = db_config[DB_SECRET_T]
-    return mapping
-
-
 def import_dbs(db, db_mappings, mapping_name):
     """
     Function to go over each service defined in the DB and assign found DB settings to service
@@ -107,27 +80,6 @@ def import_dbs(db, db_mappings, mapping_name):
         handle_import_dbs_to_services(db, db_mappings, target, mapping_name)
 
 
-def create_lookup_mappings(mappings, lookup_dbs, settings):
-    """
-    Function to create the RDS mappings to add to services templates
-
-    :param dict mappings:
-    :param list lookup_dbs:
-    :param ecs_composex.common.settings.ComposeXSettings settings: The settings for ComposeX Execution
-    """
-    for db in lookup_dbs:
-        validate_rds_lookup(db.name, db.lookup)
-        db_config = lookup_rds_resource(db.lookup, settings.session)
-        if not db_config:
-            LOG.warning(
-                f"No RDS DB Configuration could be defined from provided lookup. Skipping {db.name}"
-            )
-            return
-        config = create_rds_db_config_mapping(db, db_config)
-        mappings.update(config)
-        db.mappings = db_config
-
-
 def rds_to_ecs(rds_dbs, services_stack, res_root_stack, settings):
     """
     Function to apply onto existing ECS Templates the various settings
@@ -138,7 +90,7 @@ def rds_to_ecs(rds_dbs, services_stack, res_root_stack, settings):
     :param ecs_composex.common.settings.ComposeXSettings settings: The settings for ComposeX Execution
     :return:
     """
-    db_mappings = {}
+    print("SETTINGS", settings.mappings.keys())
     new_resources = [
         rds_dbs[db_name]
         for db_name in rds_dbs
@@ -157,7 +109,6 @@ def rds_to_ecs(rds_dbs, services_stack, res_root_stack, settings):
             secret_parameter=DB_SECRET_ARN,
             sg_parameter=DB_SG,
         )
-    create_lookup_mappings(db_mappings, lookup_resources, settings)
     for lookup_res in lookup_resources:
-        if keyisset(lookup_res.logical_name, db_mappings):
-            import_dbs(lookup_res, db_mappings, mapping_name="Rds")
+        if keyisset(lookup_res.logical_name, settings.mappings[RES_KEY]):
+            import_dbs(lookup_res, settings.mappings[RES_KEY], mapping_name="Rds")
