@@ -10,7 +10,6 @@ from ecs_composex.resource_settings import (
     handle_lookup_resource,
     handle_resource_to_services,
 )
-from ecs_composex.ssm_parameter.ssm_parameter_aws import lookup_param_config
 from ecs_composex.ssm_parameter.ssm_parameter_params import (
     RES_KEY,
     SSM_PARAM_ARN,
@@ -18,21 +17,6 @@ from ecs_composex.ssm_parameter.ssm_parameter_params import (
 )
 
 
-def create_ssm_param_mappings(mapping, resources, settings):
-    """
-    Function to create the resource mapping for SQS Queues.
-
-    :param dict mapping:
-    :param list[ecs_composex.ssm_parameter.ssm_parameter_stack.SsmParameter] resources:
-    :param ecs_composex.common.settings.ComposeXSettings settings:
-    :return:
-    """
-    for res in resources:
-        res_config = lookup_param_config(res.lookup, settings.session)
-        res.mappings = res_config
-        mapping.update({res.logical_name: res.mappings})
-
-
 def ssm_parameter_to_ecs(resources, services_stack, res_root_stack, settings):
     """
     Function to apply SSM Parameters settings to ECS Services
@@ -46,9 +30,7 @@ def ssm_parameter_to_ecs(resources, services_stack, res_root_stack, settings):
     lookup_resources = [
         resources[res_name]
         for res_name in resources
-        if resources[res_name].lookup
-        and not resources[res_name].properties
-        and not resources[res_name].use
+        if resources[res_name].mappings and not resources[res_name].use
     ]
     for new_res in new_resources:
         handle_resource_to_services(
